/* ~Օʉ
 * Copyright (C) 2004 Kagetani Hideto
 */
#ifndef __OPTION_H__
#define __OPTION_H__

#include <aspi.h>
#include "cmd.h"

typedef struct {
	int read_speed;		/* 0 ōő呬 */
	int write_speed;	/* 0 ōő呬 */
	BOOL bufe;			/* Buffer Underrun Free Enable */
	BOOL test_write;	/* Test write */
	BOOL on_the_fly;	/* on-the-fly */
	BOOL dao;			/* Disc at once */
	WORD flags;			/* Lȍڂ */
	char temppath[_MAX_PATH];
} OPTIONS;

/* flags value */
#define OPFLG_BUFE		(1<<0)
#define OPFLG_TESTWRITE	(1<<1)
#define OPFLG_ONTHEFLY	(1<<2)
#define OPFLG_DAO		(1<<3)
#define OPFLG_TEMPPATH	(1<<4)
#define OPFLG_DVD		(1<<5)	// DVDnǂ

#ifdef __cplusplus
extern "C" {
#endif
	
extern int SetOption(CMDDRIVE *reader, CMDDRIVE *writer, int disc_type);
extern OPTIONS *GetOption();

#if defined(WIN32)
void GetRegString(const char *key, char *string_ret, DWORD size);
void WriteRegString(const char *key, const char *string);
#endif /* WIN32 */

#ifdef __cplusplus
}
#endif


#endif /* !__OPTION_H__ */

